<?php
include("../config/session.php");
checkSession();

// Conexión a la base de datos
include("../config/lgcn.php");

// Establece el tipo de contenido de la respuesta a JSON
header('Content-Type: application/json');

// Inicializa la variable $response para almacenar la respuesta
$response = [];

try {
    // Obtener el nombre de la base de datos desde la sesión
    $bd = $_SESSION['v_nombasedato'];
    $cn = getConnection($bd);

    // Verificar si el ID de la empresa está establecido en la sesión
    if (!isset($_SESSION['v_idempresa'])) {
        throw new Exception("ID de empresa no establecido en la sesión.");
    }

    // Obtener los parámetros de búsqueda y paginación
    $searchTerm = isset($_POST['search']) ? $_POST['search'] : '';
    $page = isset($_POST['page']) ? (int)$_POST['page'] : 1;
    $itemsPerPage = 30;
    $offset = ($page - 1) * $itemsPerPage;

    // Construir la consulta SQL con SQL_CALC_FOUND_ROWS para obtener el total de resultados
    $sql = "SELECT SQL_CALC_FOUND_ROWS id_Pro, Descripcion_Larga, idlote, nrolote, UndReal, Precioventa_lt, Preciocompra_lt, fotoprodlt, 
            nombreLab, Categoria, grupocategorico,fechavence, FormaVenta 
            FROM v_productos_ydependientes 
            WHERE id_empre = :id_empresa";
    if ($searchTerm) {
        $sql .= " AND Descripcion_Larga LIKE :searchTerm";
    }
    $sql .= " LIMIT :offset, :itemsPerPage";

    // Preparar la consulta SQL
    $stmt = $cn->prepare($sql);
    $stmt->bindParam(':id_empresa', $_SESSION['v_idempresa'], PDO::PARAM_INT);
    if ($searchTerm) {
        $stmt->bindValue(':searchTerm', '%' . $searchTerm . '%', PDO::PARAM_STR);
    }
    $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
    $stmt->bindParam(':itemsPerPage', $itemsPerPage, PDO::PARAM_INT);
    $stmt->execute();
    $productos = $stmt->fetchAll(PDO::FETCH_ASSOC);   

    // Convertir todos los valores a UTF-8 para evitar errores de codificación
    //array_walk_recursive($productos, function(&$item, $key) {
    //    if (!mb_check_encoding($item, 'UTF-8') || !($item === mb_convert_encoding(mb_convert_encoding($item, 'UTF-32', 'UTF-8'), 'UTF-8', 'UTF-32'))) {
    //        $item = mb_convert_encoding($item, 'UTF-8', 'auto');
    //    }
   // });


    array_walk_recursive($productos, function(&$item, $key) {
        if (!is_string($item)) {
            return; // Solo intentamos convertir cadenas
        }
        
        // Intentar detectar la codificación actual
        $encoding = mb_detect_encoding($item, 'UTF-8, ISO-8859-1, ISO-8859-15', true);
        
        if ($encoding !== 'UTF-8') {
            // Si la codificación detectada no es UTF-8, intentamos convertirla
            $item = mb_convert_encoding($item, 'UTF-8', $encoding);
        }
    });
    
    // Guardar los datos obtenidos en un archivo de depuración
    //file_put_contents('debug_log1_prod.txt', "Productos: " . print_r($productos, true), FILE_APPEND);
    
    // Ejecutar FOUND_ROWS() para obtener el total de elementos
   // $stmt = $cn->query("SELECT FOUND_ROWS()");
    //if ($stmt === false) {
   //     file_put_contents('debug_log2_rows.txt', "Error: Consulta FOUND_ROWS() fallida.\n", FILE_APPEND);
   //     exit;
   // }
   $stmt = $cn->query("SELECT FOUND_ROWS()");
    $totalItems = $stmt->fetchColumn();
    $totalPages = ceil($totalItems / $itemsPerPage);

    // Guardar la información de paginación en un archivo de depuración
    //file_put_contents('debug_log4_tlitem.txt', "TotalItems: $totalItems, TotalPages: $totalPages\n", FILE_APPEND);

    // Guardar la página actual en un archivo de depuración
    //file_put_contents('debug_log5_page.txt', "Page: $page\n", FILE_APPEND);

    // Crear el JSON con los datos obtenidos
    $json_data = json_encode([
        'productos' => $productos,
        'page' => $page,
        'totalPages' => $totalPages
    ]);

    // Verificar errores de JSON y guardarlos en un archivo de depuración
    if (json_last_error() !== JSON_ERROR_NONE) {
        file_put_contents('debugjay_log6_jayerror.txt', "JSON Error: " . json_last_error_msg() . PHP_EOL, FILE_APPEND);
    }

    // Devolver los datos como JSON
    echo $json_data;

    // Guardar el JSON en un archivo de depuración
    //file_put_contents('debug_log7_jaydata.txt', $json_data . PHP_EOL, FILE_APPEND);

} catch (PDOException $e) {
    // Manejar errores de la consulta a la base de datos
    echo json_encode(["error" => "Error en la consulta: " . $e->getMessage()]);
} catch (Exception $e) {
    // Manejar otros errores
    echo json_encode(["error" => "Error: " . $e->getMessage()]);
}
?>
