<?php
include("../config/session.php");
checkSession();

// Conexión a la base de datos
include("../config/lgcn.php");

// Establece el tipo de contenido de la respuesta
header('Content-Type: application/json');

// Inicializa la variable $response
$response = [];

try {
    $bd = $_SESSION['v_nombasedato'];
    $cn = getConnection($bd);

    if (!isset($_SESSION['v_idempresa'])) {
        throw new Exception("ID de empresa no establecido en la sesión.");
    }

    $searchTerm = isset($_POST['search']) ? $_POST['search'] : '';
    $page = isset($_POST['page']) ? (int)$_POST['page'] : 1;
    $itemsPerPage = 100;
    $offset = ($page - 1) * $itemsPerPage;

    $sql = "SELECT SQL_CALC_FOUND_ROWS id_Pro, Descripcion_Larga, idlote, nrolote, UndReal, Precioventa_lt, Preciocompra_lt, fotoprodlt, 
            nombreLab, Categoria, grupocategorico, FormaVenta 
            FROM v_productos_ydependientes 
            WHERE id_empre = :id_empresa";
    if ($searchTerm) {
        $sql .= " AND Descripcion_Larga LIKE :searchTerm";
    }
    $sql .= " LIMIT :offset, :itemsPerPage";

    $stmt = $cn->prepare($sql);
    $stmt->bindParam(':id_empresa', $_SESSION['v_idempresa'], PDO::PARAM_INT);
    if ($searchTerm) {
        $stmt->bindValue(':searchTerm', '%' . $searchTerm . '%', PDO::PARAM_STR);
    }
    $stmt->bindParam(':offset', $offset, PDO::PARAM_INT);
    $stmt->bindParam(':itemsPerPage', $itemsPerPage, PDO::PARAM_INT);
    $stmt->execute();
    $productos = $stmt->fetchAll(PDO::FETCH_ASSOC);   

    // Convertir todos los valores a UTF-8
array_walk_recursive($productos, function(&$item, $key) {
    if (!mb_check_encoding($item, 'UTF-8') || !($item === mb_convert_encoding(mb_convert_encoding($item, 'UTF-32', 'UTF-8' ), 'UTF-8', 'UTF-32'))) {
        $item = mb_convert_encoding($item, 'UTF-8', 'auto');
    }
});

    
    // Depuración para verificar $productos
    file_put_contents('debug_log1_prod.txt', "Productos: " . print_r($productos, true), FILE_APPEND);
    
   

    // Ejecutar FOUND_ROWS() para obtener el total de elementos
        $stmt = $cn->query("SELECT FOUND_ROWS()");
        if ($stmt === false) {
            file_put_contents('debug_log2_rows.txt', "Error: Consulta FOUND_ROWS() fallida.\n", FILE_APPEND);
            exit;
        }

    $totalItems = $stmt->fetchColumn();
    $totalPages = ceil($totalItems / $itemsPerPage);

    // Depuración para verificar $totalItems y $totalPages
    file_put_contents('debug_log4_tlitem.txt', "TotalItems: $totalItems, TotalPages: $totalPages\n", FILE_APPEND);

    // Verificar si $page está definido correctamente
    file_put_contents('debug_log5_page.txt', "Page: $page\n", FILE_APPEND);
        
     
// Crear el JSON
    $json_data = json_encode([
        'productos' => $productos,
        'page' => $page,
        'totalPages' => $totalPages
    ]);

    // Verificar errores de JSON
if (json_last_error() !== JSON_ERROR_NONE) {
    file_put_contents('debugjay_log6_jayerror.txt', "JSON Error: " . json_last_error_msg() . PHP_EOL, FILE_APPEND);
}
    
    // Devolver los datos como JSON
    echo $json_data;
    
    // Guardar el JSON en el archivo de depuración
    file_put_contents('debug_log7_jaydata.txt', $json_data . PHP_EOL, FILE_APPEND);
    

    /*

    // Devolver los datos como JSON
    echo json_encode([
        'productos' => $productos,
        'page' => $page,
        'totalPages' => $totalPages
    ]);

    file_put_contents('debug_log22.txt', print_r($productos, true), FILE_APPEND);
*/
} catch (PDOException $e) {
    echo json_encode(["error" => "Error en la consulta: " . $e->getMessage()]);
    echo json_encode($response);
} catch (Exception $e) {
    echo json_encode(["error" => "Error: " . $e->getMessage()]);
    echo json_encode($response);
    exit();
}
?>
